<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.neteuro.pt
 * @since      1.0.0
 *
 * @package    Easy_Javascript_Analytics_Goals
 * @subpackage Easy_Javascript_Analytics_Goals/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Easy_Javascript_Analytics_Goals
 * @subpackage Easy_Javascript_Analytics_Goals/admin
 * @author     Neteuro <dev@neteuro.pt>
 */

include_once(ANALYTICS_GOALS_PLUGIN_PATH."admin/includes/inc.php");

class Easy_Javascript_Analytics_Goals_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		add_action( 'admin_menu', array( $this, 'ejag_admin_menu' ) );
		add_action( 'plugin_action_links_' . EJAG_PLUGIN_BASENAME, array( $this, 'ejag_admin_action_links'));

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Javascript_Analytics_Goals_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Javascript_Analytics_Goals_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/easy-javascript-analytics-goals-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Javascript_Analytics_Goals_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Javascript_Analytics_Goals_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/easy-javascript-analytics-goals-admin.js?t='.time(), array( 'jquery' ), $this->version, false );
		wp_localize_script($this->plugin_name, 'EJAG', array(
			'url' => admin_url('admin-ajax.php'),
			'nonce' => wp_create_nonce('ajax-nonce')
		));
	}

	function ejag_admin_menu() {
		$hook = add_management_page( 'Easy JS Analytics Goals', 'Easy JS Analytics Goals', 'install_plugins', 'easy-javascript-analytics-goals', array( $this, 'ejag_admin_page' ) );
		//add_action( "load-$hook", array( $this, 'admin_page_load' ) );
	}

	function ejag_admin_page_load() {

	}

	function ejag_admin_page() {
		$goals = json_decode(get_option( 'ejag_goals', '[]' ));
		include_once(plugin_dir_path( __FILE__ ) .'partials/easy-javascript-analytics-goals-admin-display.php');
	}


	function ejag_admin_action_links ( $actions ) {
		$mylinks = array(
			'<a href="' . esc_url( admin_url( 'tools.php?page=easy-javascript-analytics-goals' ) ) . '">' . __( 'Goals', 'EJAG' ) . '</a>'
		);
		$actions = array_merge( $actions, $mylinks );
		return $actions;
	}
}
