<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.neteuro.pt
 * @since             1.0.0
 * @package           Easy_Javascript_Analytics_Goals
 *
 * @wordpress-plugin
 * Plugin Name:       Easy Javascript Analytics Goals
 * Plugin URI:        https://www.neteuro.pt
 * Description:       Setup javascript with google analytics goals
 * Version:           1.0.6
 * Author:            Neteuro
 * Author URI:        https://www.neteuro.pt
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       easy-javascript-analytics-goals
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.1 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'EASY_JAVASCRIPT_ANALYTICS_GOALS_VERSION', '1.0.6' );
define( 'ANALYTICS_GOALS_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'EJAG_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-easy-javascript-analytics-goals-activator.php
 */
function activate_easy_javascript_analytics_goals() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-easy-javascript-analytics-goals-activator.php';
	Easy_Javascript_Analytics_Goals_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-easy-javascript-analytics-goals-deactivator.php
 */
function deactivate_easy_javascript_analytics_goals() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-easy-javascript-analytics-goals-deactivator.php';
	Easy_Javascript_Analytics_Goals_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_easy_javascript_analytics_goals' );
register_deactivation_hook( __FILE__, 'deactivate_easy_javascript_analytics_goals' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-easy-javascript-analytics-goals.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_easy_javascript_analytics_goals() {

	$plugin = new Easy_Javascript_Analytics_Goals();
	$plugin->run();

}
run_easy_javascript_analytics_goals();
