<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.neteuro.pt
 * @since      1.0.0
 *
 * @package    Easy_Javascript_Analytics_Goals
 * @subpackage Easy_Javascript_Analytics_Goals/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Easy_Javascript_Analytics_Goals
 * @subpackage Easy_Javascript_Analytics_Goals/public
 * @author     Neteuro <dev@neteuro.pt>
 */
class Easy_Javascript_Analytics_Goals_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Javascript_Analytics_Goals_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Javascript_Analytics_Goals_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/easy-javascript-analytics-goals-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Easy_Javascript_Analytics_Goals_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Easy_Javascript_Analytics_Goals_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/easy-javascript-analytics-goals-public.js', array( 'jquery' ), $this->version, false );

	}

}


function ejag_activateGoals() {
	$goals = get_option('ejag_goals','[]');

	$goals = json_decode($goals);
	?>
	<!-- Start Easy Js Analytics Goals -->
	<script type='text/javascript'>
		jQuery(function($) {
			<?php
			foreach($goals as $goal){
				if($goal->isactive == 0) continue;
				?>
				$(document).on('<?php echo esc_attr($goal->type) ?>','<?php echo html_entity_decode(esc_attr($goal->classes))?>',function(){
					gtag('event','<?php echo esc_attr($goal->action) ?>', { event_category: '<?php echo esc_attr($goal->category)?>'});
				});
				<?php
			}
			?>
		} ); 
	</script>
	<!-- End Easy Js Analytics Goals -->
	<?php
}
add_action( 'wp_footer',  'ejag_activateGoals' );
